Index: uspace/srv/net/inetsrv/inet_link.c
===================================================================
--- uspace/srv/net/inetsrv/inet_link.c	(revision 3e6a98c595287c43d200d28d97f57755342be117)
+++ uspace/srv/net/inetsrv/inet_link.c	(revision c90aed45894edfe6e38e6306948757008e2bb0eb)
@@ -196,5 +196,5 @@
 
 	static int first = 1;
 	/* XXX For testing: set static IP address 192.168.0.4/24 */
 	addr = inet_addrobj_new();
 	if (first) {
@@ -202,5 +202,5 @@
 		first = 0;
 	} else {
-		addr->naddr.ipv4 = (192 << 24) + (168 << 16) + (0 << 8) + 4;
+		addr->naddr.ipv4 = (10 << 24) + (0 << 16) + (2 << 8) + 15;
 	}
 	addr->naddr.bits = 24;
@@ -196,5 +196,5 @@
 
 	static int first = 1;
-	/* XXX For testing: set static IP address 192.168.0.4/24 */
+	/* XXX For testing: set static IP address 10.0.2.15/24 */
 	addr = inet_addrobj_new();
 	if (first) {
